# PortX
**Python library for the RedRobotics PPX - Programmable Port eXpander**  
A stackable add-on board for the Raspberry Pi computer. Use it with or without the [RedBoard+](https://github.com/RedRobotics/RedBoard) robotics controller, to add 12 GPIO pins which can be configured as:
- Digital IO
- PWM
- ADC
- Quadrature Encoder Interface    
